<lare-head>
    <title>{% block title %}{% block inner_title %}{% endblock inner_title %}{% endblock title %}</title>
    {% block inner_head %}{% endblock inner_head %}
</lare-head>
<lare-body>
    {% block site %}
        {% block page %}
            {% block content %}
                {% block inner_content %}{% endblock inner_content %}
            {% endblock content %}
        {% endblock page %}
    {% endblock site %}
    {% block additional_lare_includes %}{% endblock additional_lare_includes %}
</lare-body>
<lare-namespace>{% block lare_namespace %}{{ lare.current_namespace }}{% endblock lare_namespace %}</lare-namespace>
