<!Doctype html>
<html>
<head>
    <title>{% block title %}{% block inner_title %}{% endblock inner_title %}{% endblock title %}</title>
    {% block inner_head %}{% endblock inner_head %}
</head>
<body data-lare-namespace="{% block lare_namespace %}{{ lare.current_namespace }}{% endblock lare_namespace %}">
    {% block site %}
        <div id="site">
            {{ site_string }}
            {% block page %}
                {% block content %}
                    {% block inner_content %}{% endblock inner_content %}
                {% endblock content %}
            {% endblock page %}
        </div>
    {% endblock site %}
</body>
</html>
